import json

from flask import Blueprint, Response, current_app, jsonify
from inventory_provider.routes import common

routes = Blueprint("inventory-data-testing-support-routes", __name__)


@routes.route("/flushdb", methods=['GET', 'POST'])
def flushdb():
    common.get_redis().flushdb()
    return Response('OK')


@routes.route("/infinera-dna-addresses", methods=['GET', 'POST'])
@common.require_accepts_json
def infinera_addresses():
    infinera_config = current_app.config[
        "INVENTORY_PROVIDER_CONFIG"]["infinera-dna"]
    return jsonify([dna['address'] for dna in infinera_config])


@routes.route("/coriant-tnms-addresses", methods=['GET', 'POST'])
@common.require_accepts_json
def coriant_addresses():
    coriant_config = current_app.config[
        "INVENTORY_PROVIDER_CONFIG"]["coriant-tnms"]
    return jsonify([tnms['address'] for tnms in coriant_config])


@routes.route("/juniper-server-addresses", methods=['GET', 'POST'])
@common.require_accepts_json
def juniper_addresses():
    # TODO: this route (and corant, infinera routes) can be removed
    r = common.get_redis()
    routers = []
    for k in r.keys('junosspace:*'):
        info = r.get(k.decode('utf-8'))
        assert info  # sanity: value shouldn't be empty
        info = json.loads(info.decode('utf-8'))
        routers.append(info['address'])
    return jsonify(routers)
